#
# spec file for package bat
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bat
Version:        0.17.1
Release:        bp153.1.38
Summary:        A cat(1) clone with syntax highlighting and Git integration
License:        MIT OR Apache-2.0
Group:          Productivity/Text/Utilities
URL:            https://github.com/sharkdp/bat
Source0:        https://github.com/sharkdp/bat/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
# Instructions on how to generate vendor.tar.xz
Source2:        README.packager
BuildRequires:  cargo
BuildRequires:  clang
BuildRequires:  cmake
BuildRequires:  rust
BuildRequires:  rust-std-static
BuildRequires:  zlib-devel

%description
A cat(1) clone which supports syntax highlighting for a large number of
programming and markup languages. It has git integration and automatic paging.

%prep
%setup -qa1
mkdir .cargo
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
cargo build --release --locked %{?_smp_mflags}

%install
cargo install --no-track --root=%{buildroot}%{_prefix} --path .

%files
%doc README.md
%license LICENSE-MIT LICENSE-APACHE
%{_bindir}/bat

%changelog
* Mon Dec  7 2020 Gordon Schulz <gordon@gordonschulz.de>
- Update to 0.17.1
  * Features
  - Added a new --style value, rule, which adds a simple horizontal
    ruled line between files, see #1276 (@tommilligan)
  - Pass -S ("chop long lines") to less if --wrap=never is set in
    bat, see #1255 (@gahag)
  - Added support for the NO_COLOR environment variable, see #1021
    and #1031 (@eth-p)
  - Added -P short flag to disable paging, see #1075 and #1082
    (@LordFlashmeow)
  - Added --force-colorization/-f flag to provide an alias for
    forced color and decoration output, see #1141
    (@alexanderkarlis)
  * Bugfixes
  - Running bat without arguments fails ("output file is also
    an input"), see #1396
  - Detect infinite loop when input and output are the same, see
    [#1193] and #1197 (@niklasmohrin)
  - Throw an error when bat is being used as pager, see #1343
    (@adrian-rivera)
  - Bash syntax highlighting not selected for *.ebuild and *.eclass
    files, see #1292 (@sharkdp)
  - Fix zsh completion when using -p, see #1320 (@xzfc)
  - Fixed non-printable characters display for redirected output,
    see #1061 (@gsomix)
  - Handle file extension conflicts in --list-languages, see #1076
    and #1135 (@Kienyew)
  * Other
  - Add note to refer to see detailed help with --help (and vice
    versa with -h), see #1215 (@henil)
  - Add a Contributors section to README, see #1348
    (@adrian-rivera)
  - Switched to "·" (U+00B7) Middle Dot from "•" (U+2022) Bullet
    for non-printing spaces, see #1056 and #1100 (@LordFlashmeow)
  - Added zsh shell completion script, see #1136 (@Kienyew)
  - Improved --help text (@sharkdp)
  - Added custom languages/themes sections to manpage (@eth-p)
  * Syntaxes
  - Manpage syntax highlighting has been improved, see #1315
    (@keith-hall)
  - Add Svelte file syntax, see #1285 (@kjmph)
  - Update AsciiDoc syntax, see #1034 (@rxt1077)
  - GLSL (@caioalonso)
  - Add Nginx and Apache config file syntax, see #1137 (@kjmph,
    @niklasmohrin)
  - Use fstab syntax for crypttab files, see #1073 (@sharkdp)
  - Support syntax highlighting for files in $XDG_CONFIG_HOME/git/,
    see #1191 (@ahmedelgabri)
  * New themes
  - Coldark, see #1329 (@ArmandPhilippot)
  - Gruvbox, see #1069 (@KyleOndy)
  - base16-256 for base16-shell users, see #1111 (@mk12)
  * bat as a library
  - Add APIs to provide Input descriptions with InputDescription (@eth-p)
  - Add function to directly provide Inputs to PrettyPrinter (@eth-p)
  - Breaking: Input::theme_preview_file is no longer available. (@eth-p)
  * Packaging
  - Package maintainers: note that we now include zsh shell completion files
  - Removed build dependency on liquid (@sharkdp).
* Mon Jun  1 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.15.4
  * Added missing Solarized themes
  * Fixed highlighting bug in Haskell source files
  * Cannot run bat with relative paths
  * bat mishighlights Users that start with digits in SSH config
  * --map-syntax doesn't work with names provided through --file-name
  * Fix syntax detection for files called 'rails'
  * Fix potential errors with syntax detection for symlinked files
  * Fix highlighting of Markdown files
* Mon May  4 2020 Martin Rey <mrey@suse.com>
- Update to version 0.15.0
  * Features
  - This release adds a new --diff/-d option that can be used to
    only show lines surrounding Git changes, i.e. added, removed
    or modified lines. The amount of additional context can be
    controlled with --diff-context=N. See #23 and #940
  * Bugfixes
  - Error message printed in the middle of the output for another
    file, see #946
    Performance improvements when using custom caches (via bat
    cache --build): the bat startup time should now be twice as
    fast.
  * Themes
  - Updated version of the Solarized dark/light themes, see #941
  * bat as a library
  - There are a few changes in the "low level" API (the Config
    struct has changed andthe error handler needs a new &mut dyn
    Write argument). The high-level API is not affected.
- Changes from version 0.14.0
  * Features
  - Added a new --file-name <name>… option to overwrite the
    displayed filename(s) in the header. This is useful when
    piping input into bat. See #654 and #892.
  - Added a new --generate-config-file option to create an
    initial configuration file at the right place. See #870.
  * Bugfixes
  - Performance problems with C# source code have been fixed, see
    [#677]
  - Performance problems with Makefiles have been fixed, see #750
  - Fix bug when highlighting Ruby files with unindented heredocs
    , see #914
  - A highlighting problem with Rust source code has been fixed,
    see #924
  - --highlight-line did not work correctly in combination with
  - -tabs=0 and --wrap=never, see #937
  * Other
  - When saving/reading user-provided syntaxes or themes, bat
    will now maintain a metadata.yaml file which includes
    information about the bat version which was used to create
    the cached files. When loading cached files, we now print an
    error if they have been created with an incompatible version.
    See #882
  - Updated liquid dependency to 0.20, see #880
  * bat as a library
  - A completely new "high level" API has been added that is much
    more convenient to use. See the examples folder for the
    updated code. It is recommended to only use the new
    "high level" API, if possible. Note that this should still
    be considered a "beta" release of bat-as-a-library.
    For more details and some screenshots of the example
    programs, see #936.
  - Stripped out a lot of binary-only dependencies, see #895 and
    [#899]
  - Allow using the library with older syntect, see #896 and #898
  * New syntaxes
  - Rego, see #872
  - Stylo, see #917
* Thu Apr  9 2020 Dany Marcoux <dmarcoux@suse.com>
- Update to version 0.13.0
  * Beginning with this release, bat can be used as a library
  * (Breaking change) Glob-based syntax mapping
  * Many bugfixes and new syntaxes
  * And more... see upstream
- Pass "no-track" option to "cargo install" to avoid generating
  ".crates2.json"
* Tue Oct 15 2019 Dany Marcoux <dmarcoux@suse.com>
- Instruct packager to install cargo directly from the cargo package
* Tue Oct  1 2019 Luke Jones <luke@ljones.dev>
- Use `pwd`/.cargo for vendor config so that CARGO_HOME export is
  not required.
* Tue Sep 24 2019 Dany Marcoux <dmarcoux@suse.com>
- Update to version 0.12.1
  * Features
    Binary file content can now be viewed with bat -A
    bat can now be used as a man pager
    Add new style component to separate multiple '--line-range'
    Added '-L' as an alias for '--list-languages'
  * Bugfixes
    Output looks unbalanced when using '--style=grid,numbers' without 'header'
    Issues with filenames starting with "cache"
    '--terminal-width -10' is parsed incorrectly
  * New syntaxes
    Emacs Org mode
    requirements.txt
    DotENV '.env'
    SSH config
    And more... see upstream
- Set directory for 'git clone' in README.packager
- Add 'clang' to build dependencies
* Wed May 15 2019 Dany Marcoux <dmarcoux@suse.com>
- Update to version 0.11.0
  * Features
    New color themes: ansi-light, ansi-dark and base16
    The -p/--plain option can be used twice (typically -pp). First -p switches --style to "plain", second disables pager.
  * Bugfixes
    Do not replace arguments to less when using --pager
    Empty files are (once again) printed with a single header line
  - -terminal-width=0 is now disallowed
  * New syntaxes
    Fish
    Update for F#
* Tue Apr 30 2019 Dany Marcoux <dmarcoux@suse.com>
- Run spec-cleaner
- Remove double %%setup macro
- Simplify tar command in README.packager
* Mon Feb 11 2019 Dany Marcoux <dmarcoux@posteo.de>
- Add README.packager for instructions on how to generate vendor.tar.xz
- Update to version 0.10.0
  * Features
    New option --highlight-line <N>
    New option -A/--show-all to show and highlight non-printable characters (in analogy to GNU cats option)
    New option --pager to configure the pager
    Support for a configuration file (https://github.com/sharkdp/bat#format)
    Support for custom config file path via --config-file option or BAT_CONFIG_PATH environment variable
    Support for custom syntax mappings via the -m/--max-syntax option
    Support pager command-line arguments in PAGER and BAT_PAGER
    The --terminal-width option can now also accept offsets
    Support for multiple --line-range arguments
    Encoding support for UTF-16LE and UTF-16BE
  * Changes
    Completely disabled the generation of shell completion files
    Report the name of missing files
    Don't start pager if file doesn't exist
    Rename bat cache --init to bat cache --build
    Move the --config-dir and --cache-dir options from bat cache to bat and hide them from the help text
    The default tab-width has been set to 4
  * New syntaxes supported
    Robot framework, Twig, .desktop files, AsciiDoc, Assembly, Jsonnet,
    Log files, Protobuf and ProtobufText, Terraform and Varlink
* Tue Oct  2 2018 Jan Engelhardt <jengelh@inai.de>
- Fix the description's grammar.
* Mon Sep 24 2018 dmarcoux@posteo.de
- Update to version 0.7.1
* Sat Aug 25 2018 viktor.saevars@gmail.com
- Inital packaging @ 0.5.0
